/*
 * avrisp.h
 * by Stephan Brwolf, Ilmenau 2013
 * 
 * This file headers the software SPI library.
 */

#ifndef __AVRISP_H_229db984fe7b4d419c4c43c9ad0e2028
#	define __AVRISP_H_229db984fe7b4d419c4c43c9ad0e2028 1

#include "softspi.h"
#include <stdint.h>

#ifndef __AVRISP_C_229db984fe7b4d419c4c43c9ad0e2028
#	define AVRISPPUBLIC
#else
#	define AVRISPPUBLIC extern
#endif


/*
 * Initialisation- and finalizationfunctions of the ISP
 * Returns value "0" (or positive) if successful
 * otherwise it means FAIL (and no changes done)
 */
AVRISPPUBLIC int avrisp_initialize(void);
AVRISPPUBLIC int avrisp_finalize(void);
AVRISPPUBLIC int avrisp_isinitialized(void);


/*
 * selfexplaining
 */
AVRISPPUBLIC int avrisp_enable(void);
AVRISPPUBLIC int avrisp_disable(void);


/*
 * reads AVR chip signature and returns it in
 * intels endianness.
 * If input is not supported by softspi it reads as "0"
 */
AVRISPPUBLIC uint32_t avrisp_readsignature(void);
AVRISPPUBLIC uint32_t avrisp_readcalibration(void);


/*
 * all other IPS stuff
 */
AVRISPPUBLIC uint8_t avrisp_readlock(void);
AVRISPPUBLIC uint8_t avrisp_readlfuse(void);
AVRISPPUBLIC uint8_t avrisp_readhfuse(void);
AVRISPPUBLIC uint8_t avrisp_readeeprom(uint16_t byteaddress);
AVRISPPUBLIC uint8_t avrisp_readflash(uint16_t byteaddress);


AVRISPPUBLIC void avrisp_chiperase(void);
AVRISPPUBLIC void avrisp_writelock(uint8_t data);
AVRISPPUBLIC void avrisp_writelfuse(uint8_t data);
AVRISPPUBLIC void avrisp_writehfuse(uint8_t data);
AVRISPPUBLIC void avrisp_writeeprom(uint16_t byteaddress, uint8_t data);
AVRISPPUBLIC void avrisp_loadflashpage(uint16_t byteaddress, uint8_t data);
AVRISPPUBLIC void avrisp_writeflashpage(uint16_t pagestartbyteaddress);

#endif
