/*
 * keyboard.h
 * by Stephan Brwolf, Ilmenau 2013
 * 
 * This file abstracts access to the keyboard.
 * The corresponding keyboard_*.c may be platform
 * dependend and can be replaced by suitable versions.
 */

#ifndef __KEYBOARD_H_229db984fe7b4d419c4c43c9ad0e2028
#	define __KEYBOARD_H_229db984fe7b4d419c4c43c9ad0e2028 1

#include <stdlib.h>

#ifndef __KEYBOARD_C_229db984fe7b4d419c4c43c9ad0e2028
#	define KEYBOARDPUBLIC
#else
#	define KEYBOARDPUBLIC extern
#endif

#define KEYBOARD_LED_NUMLOCK	1
#define KEYBOARD_LED_CAPSLOCK	2
#define KEYBOARD_LED_SCROLLLOCK	4
#define KEYBOARD_USERDEFINEABLE	8

/*
 * Initialisation- and finalizationfunctions for the keyboard
 * Returns value "0" (or positive) if successful
 * otherwise it means FAIL (and no changes done)
 */
KEYBOARDPUBLIC int keyboard_initialize(void);
KEYBOARDPUBLIC int keyboard_finalize(void);
KEYBOARDPUBLIC int keyboard_isinitialized(void);

/*
 * check if a key was press, but DO NOT remove the key from buffer
 */
KEYBOARDPUBLIC int keyboard_keypressed(void);

/*
 * clear the keybuffer so a new keypressed can be checked
 */
KEYBOARDPUBLIC size_t keyboard_clearkeybuffer(void);

/*
 * set state of LED
 * returns "0" if everything OK, negative otherwise
 */
KEYBOARDPUBLIC int keyboard_setled(int leds, int state); 
KEYBOARDPUBLIC int keyboard_toggleled(int leds); 

#endif
