/*
 * This file implements basic example
 * using the keyboard programmer
 * 
 * by Stephan Brwolf, Ilmenau 2013
 */

#include "avrisp.h"
#include "softspi.h"

#include <unistd.h>

#include <stdlib.h>
#include <stdio.h>
#include <stdbool.h>
#include <stdint.h>


int main(int argc, char ** argv) {

  softspi_initialize();
  avrisp_initialize();

  if (softspi_isinitialized()) {
//     softspi_setcomplementmask(0xff);
    if (argc > 1) {
      softspi_setclock(atoi(argv[1]));
    }
  }

  if (avrisp_isinitialized()) {
    if (avrisp_enable()==0) {
      uint32_t i;
      
      i=avrisp_readsignature();
      fprintf(stdout,"chips signature is 0x%06x\n", (unsigned int)i);
      fprintf(stdout,"chips lockbits : 0x%02x\n", (unsigned int)avrisp_readlock());
      fprintf(stdout,"chips lfusebits: 0x%02x\n", (unsigned int)avrisp_readlfuse());
      fprintf(stdout,"chips hfusebits: 0x%02x\n", (unsigned int)avrisp_readhfuse());
      
      if ((i&0xffffff) == 0x07931e) {
// 	avrisp_chiperase();
	fprintf(stdout,"chips calibration is 0x%06x\n\n", (unsigned int)avrisp_readcalibration());

	fprintf(stdout, "found ATmega8 - reading NRWW section just for fun:");
	for (i=0x1800;i<0x2000;i++) {
	  if (i%32 == 0) fprintf(stdout, "\n");
	  fprintf(stdout, "0x%02x ", (unsigned int)avrisp_readflash(i));
	  fflush(stdout);
	}
      } else fprintf(stderr,"this example is has more functions on ATmega8\n");
    } else fprintf(stderr,"\nunable to activate program mode\n");

    fprintf(stderr,"\n\nplease unpower your controller");
    sleep(10);
    fprintf(stderr,"\n");
    avrisp_disable();
    usleep(100000);
  } else fprintf(stderr, "\ncan not initialize AVR ISP! Please use a real framebuffer terminal.\n");

  avrisp_finalize();
  softspi_finalize();
  return 0;
}
